import 'package:flutter/material.dart';

enum AnimationType {
  normal,
  fadeIn,
}

class CustomRouteTransitionsDgr {
  final BuildContext context;
  final Widget child;
  final AnimationType? animation;
  final Duration? duration;
  final bool? replacement;

  CustomRouteTransitionsDgr({
    required this.context,
    required this.child,
    this.animation = AnimationType.normal,
    this.duration = const Duration(milliseconds: 300),
    this.replacement = false,
  }) {
    //if (this.duration == null) {
    //  this.duration = new Duration(milliseconds: 300);
    //}
    switch (animation) {
      case AnimationType.normal:
        this._normalTransition();
        break;
      case AnimationType.fadeIn:
        this._fadeInTransition();
        break;
      case null:
        break;
    }
    //
  }

  void _pushPage(Route route) => Navigator.push(context, route);

  void _pushReplacementPage(Route route) =>
      Navigator.pushReplacement(context, route);

  void _normalTransition() {
    final route = MaterialPageRoute(builder: (_) => this.child);

    (this.replacement!)
        ? this._pushReplacementPage(route)
        : this._pushPage(route);
  }

  void _fadeInTransition() {
    final route = PageRouteBuilder(
        pageBuilder: (_, __, ___) => this.child,
        transitionDuration: this.duration!,
        //transitionDuration: this.duration ?? Duration(milliseconds: 300),
        transitionsBuilder: (_, animation, __, child) {
          return FadeTransition(
              child: child,
              opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
                  CurvedAnimation(parent: animation, curve: Curves.easeOut)));
        });
    (this.replacement!)
        ? this._pushReplacementPage(route)
        : this._pushPage(route);
  }
}
